==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/WilliamsPercentRIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { WilliamsPercentRIndicatorStrategy } from "./WilliamsPercentRIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let WilliamsPercentRIndicator = /*@__PURE__*/ (() => {
    class WilliamsPercentRIndicator extends StrategyBasedIndicator {
        get_yy() {
            return new WilliamsPercentRIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return WilliamsPercentRIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(WilliamsPercentRIndicator.zk));
        }
        set zj(a) {
            this.h(WilliamsPercentRIndicator.zk, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
    }
    WilliamsPercentRIndicator.$t = /*@__PURE__*/ markType(WilliamsPercentRIndicator, 'WilliamsPercentRIndicator', StrategyBasedIndicator.$);
    WilliamsPercentRIndicator.zk = /*@__PURE__*/ StrategyBasedIndicator.zg(14, WilliamsPercentRIndicator.$);
    return WilliamsPercentRIndicator;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/WilliamsPercentRIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { WilliamsPercentRIndicatorStrategy } from "./WilliamsPercentRIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let WilliamsPercentRIndicator = /*@__PURE__*/ (() => {
    class WilliamsPercentRIndicator extends StrategyBasedIndicator {
        bj() {
            return new WilliamsPercentRIndicator();
        }
        get_abq() {
            return new WilliamsPercentRIndicatorStrategy();
        }
        get abq() {
            return this.get_abq();
        }
        get_ab3() {
            return WilliamsPercentRIndicator.$;
        }
        get ab3() {
            return this.get_ab3();
        }
        get acb() {
            return typeGetValue(this.c(WilliamsPercentRIndicator.acc));
        }
        set acb(a) {
            this.h(WilliamsPercentRIndicator.acc, a);
        }
        abw() {
            return this.acb;
        }
        ab5(a) {
            this.acb = a;
        }
    }
    WilliamsPercentRIndicator.$t = /*@__PURE__*/ markType(WilliamsPercentRIndicator, 'WilliamsPercentRIndicator', StrategyBasedIndicator.$);
    WilliamsPercentRIndicator.acc = /*@__PURE__*/ StrategyBasedIndicator.ab8(14, WilliamsPercentRIndicator.$);
    return WilliamsPercentRIndicator;
})();
